=======
CHANGES
=======

0.2.3
-----

- fixed xvfb turning off option
- change default option to not download Saucelabs everytime
- ability to replace pdb with ipdb

0.2.2
-----

- ability to set xvfb-run settings

0.2.0
-----

- ability to run standard py.test tests with config

0.0.0
-------
- initialize package [sliwinski]
